@@ -19,12 +19,13 @@
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include <iostream>
+#include <sstream>
+#include <iomanip>
 using std::cerr;
 using std::endl;
 
@@ -46,29 +47,33 @@ using std::endl;
 #include "frame.h"
 #include "dvgrab.h"
 #include "raw1394util.h"
+#include "smiltime.h"
 
 extern bool g_done;
 
 pthread_mutex_t DVgrab::capture_mutex;
 pthread_t DVgrab::capture_thread;
+pthread_t DVgrab::watchdog_thread;
 Frame *DVgrab::m_frame;
 FileHandler *DVgrab::m_writer;
 
 DVgrab::DVgrab( int argc, char *argv[] ) :
 		m_port( -1 ), m_node( -1 ), m_reader_active( false ), m_autosplit( false ),
 		m_timestamp( false ), m_channel( 63 ), m_frame_count( 0 ), m_max_file_size( 1000 ),
-                m_sizesplitmode ( 0 ), m_collection_size( 0 ), m_collection_min_cut_file_size( 1 ), 
+		m_collection_size( 0 ), m_collection_min_cut_file_size( 1 ), m_sizesplitmode ( 0 ),
 		m_file_format( AVI_DV2_FORMAT ), m_open_dml( false ), m_frame_every( 1 ),
-		m_dv1394( NULL ), m_jpeg_quality( 75 ),
-		m_jpeg_deinterlace( false ), m_jpeg_width( -1 ), m_jpeg_height( -1 ),
-		m_jpeg_overwrite( false ), m_captureActive( false ), m_avc( NULL ), m_reader( NULL ),
+		m_jpeg_quality( 75 ), m_jpeg_deinterlace( false ), m_jpeg_width( -1 ), m_jpeg_height( -1 ),
+		m_jpeg_overwrite( false ),
 		m_dropped_frames( 0 ), m_interactive( false ), m_buffers( 100 ), m_total_frames( 0 ),
-		m_duration( "" ), m_timeDuration( NULL ), m_stdin( false ), m_noavc( false ),
-		m_guid( 0 ), m_timesys( false )
+		m_duration( "" ), m_timeDuration( 0 ), m_stdin( false ), m_noavc( false ),
+		m_guid( 0 ), m_timesys( false ), m_connection( 0 ), m_raw_pipe( false ),
+		m_no_stop( false ), m_timecode( false ), m_lockstep( false ),
+		m_lockstep_maxdrops( -1 ), m_lockstep_totaldrops( -1 ),
+		m_captureActive( false ), m_avc( 0 ), m_reader( 0 )
 {
-	m_frame = NULL;
-	m_writer = NULL;
-	m_dst_file_name = "dvgrab-";
+	m_frame = 0;
+	m_writer = 0;
+	m_dst_file_name = NULL;
 
 	getargs( argc, argv );
 
@@ -80,41 +85,39 @@ DVgrab::DVgrab( int argc, char *argv[] ) :
 		m_node = discoverAVC( &m_port, m_guid );
 
 	if ( ( m_interactive || ! m_stdin ) && ( ! m_noavc && m_node == -1 ) )
-		throw string( "no camera exists" );
+		throw std::string( "no camera exists" );
 
 	pthread_mutex_init( &capture_mutex, NULL );
 	if ( m_port != -1 )
 	{
+		iec61883Connection::CheckConsistency( m_port, m_node );
+
 		if ( ! m_noavc )
 		{
 			m_avc = new AVC( m_port );
-			if ( m_avc == NULL )
-				throw( "failed to initialize AV/C" );
-			m_avc->Pause( m_node );
+			if ( ! m_avc )
+				throw std::string( "failed to initialize AV/C" );
+			if ( m_interactive )
+				m_avc->Pause( m_node );
 		}
-
-		if ( m_dv1394 != NULL )
+		
+		if ( m_guid )
 		{
-			if ( strcmp( m_dv1394, "" ) == 0 && m_port != -1 )
-			{
-				char devfs[ 32 ];
-				snprintf( devfs, 32, "/dev/ieee1394/dv/host%d/PAL/in", m_port );
-				free( m_dv1394 );
-				m_dv1394 = strdup( devfs );
-			}
-			m_reader = new dv1394Reader( m_dv1394, m_channel, m_buffers );
-		}
-		else
-		{
-			m_reader = new raw1394Reader( m_port, m_channel, m_buffers );
+			m_connection = new iec61883Connection( m_port, m_node );
+			if ( ! m_connection )
+				throw std::string( "failed to establish isochronous connection" );
+			m_channel = m_connection->GetChannel();
+			sendEvent( "Established connection over channel %d", m_channel );
 		}
+		m_reader = new iec61883Reader( m_port, m_channel, m_buffers, 
+			this->testCaptureProxy, this );
 	}
 	else if ( m_stdin )
 	{
 		m_reader = new pipeReader( m_buffers );
 	}
 	else
-		throw( "invalid DV source specified" );
+		throw std::string( "invalid DV source specified" );
 
 	if ( m_reader )
 	{
@@ -125,22 +128,7 @@ DVgrab::DVgrab( int argc, char *argv[] ) :
 
 DVgrab::~DVgrab()
 {
-	stopCapture();
-	if ( m_avc )
-		m_avc->Stop( m_node );
-	m_reader_active = false;
-	if ( m_reader )
-	{
-		m_reader->StopThread();
-		pthread_join( capture_thread, NULL );
-		delete m_reader;
-	}
-	if ( m_avc )
-		delete m_avc;
-	if ( m_timeDuration )
-		delete m_timeDuration;
-	if ( m_dv1394 )
-		free( m_dv1394 );
+	cleanup();
 }
 
 static void usage()
@@ -169,6 +157,10 @@ void DVgrab::getargs( int argc, char *argv[] )
 		{
 			m_timesys = true;
 		}
+		else if ( strcmp( "--timecode", argv[ i ] ) == 0 )
+		{
+			m_timecode = true;
+		}
 		else if ( ( strcmp( "--format", argv[ i ] ) == 0 ) && ( i < argc ) )
 		{
 			i++;
@@ -220,7 +212,7 @@ void DVgrab::getargs( int argc, char *argv[] )
 			}
 		}
 		else if ( ( strcmp( "--csize", argv[ i ] ) == 0 ) && ( i < argc ) )
-		{	       
+		{
 			i++;
 			if ( sscanf( argv[ i ], "%d", &m_collection_size ) != 1 )
                         {
@@ -265,6 +257,28 @@ void DVgrab::getargs( int argc, char *argv[] )
 				exit( EXIT_FAILURE );
 			}
 		}
+		else if ( strcmp( "--lockstep", argv[ i ] ) == 0 )
+		{
+			m_lockstep = true;
+		}
+		else if ( ( strcmp( "--lockstep_maxdrops", argv[ i ] ) == 0 ) && ( i < argc ) )
+		{
+			i++;
+			if ( sscanf( argv[ i ], "%d", &m_lockstep_maxdrops ) != 1 )
+			{
+				usage();
+				exit( EXIT_FAILURE );
+			}
+		}
+		else if ( ( strcmp( "--lockstep_totaldrops", argv[ i ] ) == 0 ) && ( i < argc ) )
+		{
+			i++;
+			if ( sscanf( argv[ i ], "%d", &m_lockstep_totaldrops ) != 1 )
+			{
+				usage();
+				exit( EXIT_FAILURE );
+			}
+		}
 		else if ( strcmp( "--stdin", argv[ i ] ) == 0 )
 		{
 			m_stdin = true;
@@ -273,6 +287,10 @@ void DVgrab::getargs( int argc, char *argv[] )
 		{
 			m_noavc = true;
 		}
+		else if ( strcmp( "--nostop", argv[ i ] ) == 0 )
+		{
+			m_no_stop = true;
+		}
 		else if ( ( strcmp( "--guid", argv[ i ] ) == 0 ) && ( i < argc ) )
 		{
 			i++;
@@ -282,16 +300,6 @@ void DVgrab::getargs( int argc, char *argv[] )
 				exit( EXIT_FAILURE );
 			}
 		}
-		else if ( strcmp( "--dv1394", argv[ i ] ) == 0 )
-		{
-			if ( i + 1 < argc && argv[ i + 1 ][ 0 ] != '-' )
-			{
-				i++;
-				m_dv1394 = strdup( argv[ i ] );
-			}
-			else
-				m_dv1394 = strdup( "" ); //signal to build string from detected port
-		}
 		else if ( ( strcmp( "--card", argv[ i ] ) == 0 ) && ( i < argc ) )
 		{
 			i++;
@@ -360,14 +368,16 @@ void DVgrab::getargs( int argc, char *argv[] )
 		}
 		else if ( strcmp( "-h", argv[ i ] ) == 0 || strcmp( "--help", argv[ i ] ) == 0 )
 		{
-			fprintf( stderr, "Usage: %s [options] [file]\n\n", argv[ 0 ] );
-			fprintf( stderr, "If file is '-' or stdout is piped or redirected, then raw DV is sent to stdout.\n\n" );
+			fprintf( stderr, "Usage: %s [options] [file] [-]\n\n", argv[ 0 ] );
+			fprintf( stderr, "Use '-' to pipe raw DV to stdout.\n\n" );
 			fprintf( stderr, "Options:\n\n" );
 			fprintf( stderr, "  -i --interactive  go interactive with camera VTR and capture control!\n" );
 			fprintf( stderr, "  --noavc           disable use of AV/C VTR control\n" );
+			fprintf( stderr, "  --nostop          do not send AV/C stop command on exit\n" );
 			fprintf( stderr, "  --autosplit       start a new file when a new recording is detected\n" );
 			fprintf( stderr, "  --timestamp       put the date and time of recording into the file name.\n" );
 			fprintf( stderr, "  --timesys         put the system date and time into the file name.\n" );
+			fprintf( stderr, "  --timecode        put the first frame's timecode into the file name.\n" );
 			fprintf( stderr, "  --format dv1      save as a 'Type 1' DV AVI file. %s\n", m_file_format == AVI_DV1_FORMAT ? "This is the default." : " " );
 			fprintf( stderr, "           dv2      save as a 'Type 2' DV AVI file. %s\n", m_file_format == AVI_DV2_FORMAT ? "This is the default." : " " );
 			fprintf( stderr, "  --opendml         use the OpenDML extensions to write large (>1GB)\n" );
@@ -389,10 +399,17 @@ void DVgrab::getargs( int argc, char *argv[] )
 #endif
 
 			fprintf( stderr, "  --frames number   max number of frames per split, 0 = unlimited (default %d).\n", m_frame_count );
-			// File Sizeing Options
+			fprintf( stderr, "  --lockstep        align captures to an even multiple of --frames based upon\n" );
+			fprintf( stderr, "                      timecode.\n" );
+			fprintf( stderr, "  --lockstep_maxdrops max consecutive frame drops before closing file\n" );
+			fprintf( stderr, "                      (default -1 = unlimited).\n" );
+			fprintf( stderr, "  --lockstep_totaldrops max total frame drops permitted before closing file\n" );
+			fprintf( stderr, "                      (default -1 = unlimited).\n" );
+			// File Sizing Options
 			fprintf( stderr, "  --size number     max file size, 0 = unlimited (default %d MB).\n", m_max_file_size );
-			fprintf( stderr, "  --csize numb      Split file when collections of files are about to exceed *number* megabytes.\n" ); 
-			fprintf( stderr, "  --cmincutsize num Minimum file size due to a collection split. (default %d MB).\n", m_collection_min_cut_file_size ); 
+			fprintf( stderr, "  --csize number    split file when collections of files are about to exceed\n");
+			fprintf( stderr, "                      number megabytes.\n" ); 
+			fprintf( stderr, "  --cmincutsize num minimum file size due to a collection split. (default %d MB).\n", m_collection_min_cut_file_size ); 
 
 			fprintf( stderr, "  --every number    write every n'th frame only (default all frames).\n" );
 			fprintf( stderr, "  --duration time   total capture duration specified as a SMIL time value:\n" );
@@ -401,17 +418,14 @@ void DVgrab::getargs( int argc, char *argv[] )
 			fprintf( stderr, "                      (default unlimited).\n" );
 			fprintf( stderr, "  --card number     card number (default is automatic).\n" );
 			fprintf( stderr, "  --guid hex        select one of multiple DV devices by its GUID.\n" );
-			fprintf( stderr, "                      GUID is in hexadecimal; see /proc/bus/ieee1394/devices.\n" );
+			fprintf( stderr, "                      GUID is in hexadecimal; see /sys/bus/ieee1394/devices/.\n" );
 			fprintf( stderr, "  --channel number  iso channel number for listening (default %d).\n", m_channel );
 			fprintf( stderr, "  --buffers number  the number of internal frames to buffer (default %d).\n", m_buffers );
 			fprintf( stderr, "  --stdin           read raw DV from stdin pipe (default uses raw1394.)\n" );
-			fprintf( stderr, "  --dv1394 [device] use the dv1394 device named device (default uses raw1394.)\n" );
-			fprintf( stderr, "                      device specification is optional if you follow the dv1394\n" );
-			fprintf( stderr, "                      devfs naming convention: /dev/ieee1394/dv/hostX/....\n" );
 			fprintf( stderr, "  --help            display this help and exit.\n" );
 			fprintf( stderr, "  --version         display version information and exit.\n" );
 			fprintf( stderr, "\nCheck out the dvgrab website for the latest version, news and other software:\n" );
-			fprintf( stderr, "http://kino.schirmacher.de/\n\n" );
+			fprintf( stderr, "http://www.kinodv.org/\n\n" );
 			exit( EXIT_SUCCESS );
 		}
 		else if ( strcmp( "--version", argv[ i ] ) == 0 )
@@ -419,23 +433,23 @@ void DVgrab::getargs( int argc, char *argv[] )
 			fprintf( stderr, PACKAGE " " VERSION "\n" );
 			exit( EXIT_SUCCESS );
 		}
+		else if ( strcmp( "-", argv[ i ] ) == 0 ) {
+			m_raw_pipe = true;
+		}
 		else
 		{
 			m_dst_file_name = argv[ i ];
 		}
 	}
-	if ( m_dst_file_name == NULL && isatty( fileno( stdout ) ) )
-	{
-		usage();
-		exit( EXIT_FAILURE );
-	}
+	if ( m_dst_file_name == NULL && !m_raw_pipe )
+		m_dst_file_name = "dvgrab-";
 }
 
 void DVgrab::startCapture()
 {
 	int tryCounter = 400;
 
-	if ( strcmp( m_dst_file_name, "-" ) != 0 )
+	if ( m_dst_file_name )
 	{
 		pthread_mutex_lock( &capture_mutex );
 		switch ( m_file_format )
@@ -461,7 +475,7 @@ void DVgrab::startCapture()
 				m_writer = aviWriter;
 				if ( m_max_file_size == 0 || m_max_file_size > 1000 )
 				{
-					cerr << "Turning on OpenDML to support large file size.\n";
+					sendEvent( "Turning on OpenDML to support large file size." );
 					m_open_dml = true;
 				}
 				aviWriter->SetOpenDML( m_open_dml );
@@ -484,6 +498,7 @@ void DVgrab::startCapture()
 		}
 		m_writer->SetTimeStamp( m_timestamp );
 		m_writer->SetTimeSys( m_timesys );
+		m_writer->SetTimeCode( m_timecode );
 		m_writer->SetBaseName( m_dst_file_name );
 		m_writer->SetMaxFrameCount( m_frame_count );
 		m_writer->SetAutoSplit( m_autosplit );
@@ -522,7 +537,7 @@ void DVgrab::startCapture()
 	else
 	{
 		pthread_mutex_unlock( &capture_mutex );
-		throw string( "no DV" );
+		throw std::string( "no DV" );
 	}
 }
 
@@ -532,14 +547,14 @@ void DVgrab::stopCapture()
 	pthread_mutex_lock( &capture_mutex );
 	if ( m_writer != NULL )
 	{
-		string filename = m_writer->GetFileName();
+		std::string filename = m_writer->GetFileName();
 		int frames = m_writer->GetFramesWritten();
 		float size = ( float ) m_writer->GetFileSize() / 1024 / 1024;
 
 		m_writer->Close();
 		delete m_writer;
 		m_writer = NULL;
-		if ( m_avc )
+		if ( m_avc && m_interactive )
 			m_avc->Pause( m_node );
 		if ( m_frame != NULL )
 		{
@@ -572,6 +587,85 @@ void DVgrab::stopCapture()
 	pthread_mutex_unlock( &capture_mutex );
 }
 
+
+void DVgrab::testCapture( void )
+{
+	pthread_attr_t thread_attributes;
+
+	sendEvent( "Bus Reset, launching watchdog thread" );
+
+	pthread_attr_init( &thread_attributes );
+	pthread_attr_setdetachstate( &thread_attributes, PTHREAD_CREATE_DETACHED );
+	pthread_create( &watchdog_thread, NULL, watchdogThreadProxy, this );
+}
+
+void* DVgrab::watchdogThreadProxy( void* arg )
+{
+	DVgrab *self = static_cast< DVgrab* >( arg );
+	self->watchdogThread();
+	
+	return NULL;
+}
+
+void DVgrab::watchdogThread()
+{
+	if ( m_reader )
+	{
+		if ( ! m_reader->WaitForAction( 1 ) )
+		{
+			cleanup();
+			sendEvent( "Error: timed out waiting for DV after bus reset" );
+			throw;
+		}
+		// Otherwise, reestablish the connection
+		if ( m_connection )
+		{
+			int newChannel = m_connection->Reconnect();
+			if ( newChannel != m_channel )
+			{
+				cleanup();
+				sendEvent( "Error: unable to reestablish connection after bus reset" );
+				throw;
+
+				// TODO: the following attempt to recreate reader and restart capture
+				// does not work
+#if 0
+				bool restartCapture = m_captureActive;
+
+				if ( m_captureActive )
+					stopCapture();
+				m_reader_active = false;
+				if ( m_reader )
+				{
+					m_reader->TriggerAction( );
+					pthread_join( capture_thread, NULL );
+					m_reader->StopThread();
+					delete m_reader;
+				}		
+				sendEvent( "Closed existing reader" );
+				m_reader = new iec61883Reader( m_port, m_channel, m_buffers, 
+					this->testCaptureProxy, this );
+				if ( m_reader )
+				{
+					sendEvent( "new reader created" );
+					pthread_create( &capture_thread, NULL, captureThread, this );
+					m_reader->StartThread();
+				}
+				sendEvent( "restarting capture" );
+				if ( restartCapture )
+					startCapture();
+#endif
+			}
+		}
+	}
+}
+
+void DVgrab::testCaptureProxy( void* arg )
+{
+	DVgrab *self = static_cast< DVgrab * >( arg );
+	self->testCapture();
+}
+
 void *DVgrab::captureThread( void *arg )
 {
 	DVgrab * me = ( DVgrab* ) arg;
@@ -579,36 +673,136 @@ void *DVgrab::captureThread( void *arg )
 	return NULL;
 }
 
+void DVgrab::sendCaptureStatus( float size, TimeCode& timeCode, struct tm& recDate )
+{
+	sendEvent( "\"%s\": %8.2f MB %d frames timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
+		m_writer->GetFileName().c_str(), size, m_writer->GetFramesWritten(),
+		timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
+		recDate.tm_year + 1900, recDate.tm_mon + 1, recDate.tm_mday,
+		recDate.tm_hour, recDate.tm_min, recDate.tm_sec );
+	if ( m_dropped_frames > 0 )
+		sendEvent( "Warning: %d dropped frames.", m_dropped_frames );
+	m_dropped_frames = 0;
+}
+
+void DVgrab::writeFrame( TimeCode& timeCode, struct tm& recDate )
+{
+	// All access to the writer is protected
+	pthread_mutex_lock( &capture_mutex );
+	
+	// see if we have exceeded requested duration
+	m_total_frames++;
+	if ( m_timeDuration && m_timeDuration->isResolved() &&
+			( ( float )m_total_frames / m_frame->GetFrameRate() * 1000.0 + 0.5 ) >=
+			m_timeDuration->getResolvedOffset() )
+	{
+		pthread_mutex_unlock( &capture_mutex );
+		stopCapture();
+		m_reader_active = false;
+	}
+	else if ( m_writer != NULL )
+	{
+		// This check to split off a new file must occur outside the FileHandler
+		// so the new frame is a part of the new file and not the old one
+		// It checks for the new recording flag set in the DV stream as well as for
+		// timecode discontinuity in seconds.
+		int time_diff = timeCode.sec - m_prevTimeCode.sec;
+		bool discontinuity = m_prevTimeCode.sec != -1 && ( time_diff > 1 || ( time_diff < 0 && time_diff > -59 ) );
+		float size = ( float ) m_writer->GetFileSize() / 1024 / 1024;
+
+		if ( m_writer->FileIsOpen() && m_autosplit && ( m_frame->IsNewRecording() || discontinuity ) )
+		{
+			m_writer->CollectionCounterUpdate();
+			m_writer->Close();
+			sendCaptureStatus( size, timeCode, recDate );
+			m_lockPending = true;
+		}
+		
+		if ( m_lockstep && m_lockPending )
+		{
+			// If a lock is pending due to dropped frames, close the file
+			// TODO: still needed?
+			if ( m_writer->FileIsOpen() )
+			{
+				m_writer->CollectionCounterUpdate();
+				m_writer->Close();
+				sendCaptureStatus( size, timeCode, recDate );
+			}
+			
+			// Convert DV timecode to #frames
+			SMIL::MediaClippingTime mcTime( m_frame->GetFrameRate() );
+			std::ostringstream sb;
+			sb << setfill( '0' ) << std::setw( 2 ) 
+			<< timeCode.hour << ':' << timeCode.min << ':'
+			<< timeCode.sec << ':' << timeCode.frame;
+			if ( m_frame->IsPAL() )
+				mcTime.parseSmpteValue( sb.str() );
+			else
+				mcTime.parseSmpteNtscDropValue( sb.str() );
+				
+			// If lock step point (multiple of frame count) is reached, skip writing
+			if ( mcTime.getFrames() % m_frame_count != 0 )
+			{
+				pthread_mutex_unlock( &capture_mutex );
+				return;
+			}
+			m_lockPending = false;
+		}
+
+		// Set the sample frame here to ensure we have a good (normal speed)
+		// frame for setting audio stream format. Also, each recording could
+		// have different params.
+		if ( ! m_writer->FileIsOpen() )
+		{
+			m_writer->SetSampleFrame( *m_frame );
+		}
+
+		if ( ! m_writer->WriteFrame( *m_frame ) )
+		{
+			pthread_mutex_unlock( &capture_mutex );
+			stopCapture();
+			throw std::string( "writing failed" );
+		}
+
+		// The file will be closed by FileHandler if max size or frames are exceeded
+		if ( !m_writer->FileIsOpen() )
+		{
+			sendCaptureStatus( size, timeCode, recDate );
+			m_lockPending = true;
+		}
+	}
+	pthread_mutex_unlock( &capture_mutex );
+}
+
 void DVgrab::captureThreadRun()
 {
-	static TimeCode prevTimeCode;
-	
-	prevTimeCode.sec = -1;
+	m_lockPending = true;
+	m_prevTimeCode.sec = -1;
 	m_reader_active = true;
 
 	// Loop until we're informed otherwise
 	while ( m_reader_active )
 	{
-		int dropped = m_reader->GetDroppedFrames();
-		static TimeCode timeCode;
-		static struct tm recDate;
+		TimeCode timeCode;
+		struct tm recDate;
 
 		pthread_testcancel();
 		// Wait for the reader to indicate that something has happened
 		m_reader->WaitForAction( );
 
+		int dropped = m_reader->GetDroppedFrames();
+		int incomplete = m_reader->GetIncompleteFrames();
+
 		// Get the next frame
 		m_frame = m_reader->GetFrame();
 
 		// Check if the out queue is falling behind
 		bool critical_mass = m_reader->GetOutQueueSize( ) > m_reader->GetInQueueSize( );
 
-		// Make sure we return the oldest frame first
-		// Do with it what needs to be done
 		if ( m_frame != NULL )
 		{
+			// Get timecode and recording date/time
 			m_frame->GetTimeCode( timeCode );
-			m_frame->GetRecordingDate( recDate );
 			if ( ! m_frame->GetRecordingDate( recDate ) )
 			{
 				// If the month is invalid, then report system date/time
@@ -617,6 +811,7 @@ void DVgrab::captureThreadRun()
 				localtime_r( &timesys, &recDate );
 			}
 			
+			// Handle exceptional situations
 			if ( dropped > 0 )
 			{
 				m_dropped_frames += dropped;
@@ -626,96 +821,74 @@ void DVgrab::captureThreadRun()
 				           recDate.tm_year + 1900, recDate.tm_mon + 1, recDate.tm_mday,
 				           recDate.tm_hour, recDate.tm_min, recDate.tm_sec );
 				sendEvent( "This error means that the frames could not be written fast enough." );
+				
+				if ( m_lockstep )
+				{
+					if ( m_writer->FileIsOpen() )
+					{
+						if ( ( m_lockstep_maxdrops > -1 && dropped > m_lockstep_maxdrops )
+						||( m_lockstep_totaldrops > -1 && m_dropped_frames > m_lockstep_totaldrops ) )
+						{
+							sendEvent( "Warning: closing file early due to too many dropped frames." );
+							m_lockPending = true;
+						}
+						for ( int n = 0; n < dropped; n++ )
+							writeFrame( timeCode, recDate );
+					}
+					else
+					{
+						m_dropped_frames = 0;
+					}
+				}
+
 			}
-			if ( m_frame->IsComplete() == false )
+
+			if ( ! m_frame->IsComplete() || incomplete > 0 )
 			{
-				m_dropped_frames++;
+				if ( ! m_frame->IsComplete() )
+					m_dropped_frames++;
+				m_dropped_frames += incomplete;
 				sendEvent( "\a\"%s\": frame dropped: timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
 				           m_writer ? m_writer->GetFileName().c_str() : "stdout",
 				           timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
 				           recDate.tm_year + 1900, recDate.tm_mon + 1, recDate.tm_mday,
 				           recDate.tm_hour, recDate.tm_min, recDate.tm_sec );
 				sendEvent( "This error means that the ieee1394 driver received an incomplete frame." );
+				if ( m_lockstep )
+				{
+					if ( m_writer->FileIsOpen() )
+					{
+						if ( ( m_lockstep_maxdrops > -1 && incomplete > m_lockstep_maxdrops )
+						||( m_lockstep_totaldrops > -1 && m_dropped_frames > m_lockstep_totaldrops ) )
+						{
+							sendEvent( "Warning: closing file early due to too many incomplete frames." );
+							m_lockPending = true;
+						}
+						if ( ! m_frame->IsComplete() )
+							writeFrame( timeCode, recDate );
+						for ( int n = 0; n < incomplete; n++ )
+							writeFrame( timeCode, recDate );
+					}
+					else
+					{
+						m_dropped_frames = 0;
+					}
+				}
 			}
 			else
 			{
+				// Actually write frame unless not normal speed
 				if ( m_frame->IsNormalSpeed() )
-				{
-					// All access to the writer is protected
-					pthread_mutex_lock( &capture_mutex );
-					
-					// see if we have exceeded requested duration
-					m_total_frames++;
-					if ( m_timeDuration && m_timeDuration->isResolved() &&
-					        ( ( float )m_total_frames / m_frame->GetFrameRate() * 1000.0 + 0.5 ) >=
-					        m_timeDuration->getResolvedOffset() )
-					{
-						pthread_mutex_unlock( &capture_mutex );
-						stopCapture();
-						m_reader_active = false;
-					}
-					else if ( m_writer != NULL )
-					{
-						float size = ( float ) m_writer->GetFileSize() / 1024 / 1024;
-
-						// This check to split off a new file must occur outside the FileHandler
-						// so the new frame is a part of the new file and not the old one
-						// It checks for the new recording flag set in the DV stream as well as for
-						// timecode discontinuity in seconds.
-						int time_diff = timeCode.sec - prevTimeCode.sec;
-						bool discontinuity = prevTimeCode.sec != -1 && ( time_diff > 1 || ( time_diff < 0 && time_diff > -59 ) );
-						if ( m_writer->FileIsOpen() && m_autosplit && ( m_frame->IsNewRecording() || discontinuity ) )
-						{
-							m_writer->CollectionCounterUpdate();
-							m_writer->Close();
-							sendEvent( "\"%s\": %8.2f MB %d frames timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
-									   m_writer->GetFileName().c_str(), size, m_writer->GetFramesWritten(),
-									   timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
-									   recDate.tm_year + 1900, recDate.tm_mon + 1, recDate.tm_mday,
-									   recDate.tm_hour, recDate.tm_min, recDate.tm_sec );
-							if ( m_dropped_frames > 0 )
-								sendEvent( "Warning: %d dropped frames.", m_dropped_frames );
-							m_dropped_frames = 0;
-						}
-						// Set the sample frame here to ensure we have a good (normal speed)
-						// frame for setting audio stream format. Also, each recording could
-						// have different params.
-						if ( ! m_writer->FileIsOpen() )
-						{
-							m_writer->SetSampleFrame( *m_frame );
-						}
-						if ( ! m_writer->WriteFrame( *m_frame ) )
-						{
-							pthread_mutex_unlock( &capture_mutex );
-							stopCapture();
-							throw string( "writing failed" );
-						}
-
-						// The file will be closed if max size or frames are exceeded
-						if ( !m_writer->FileIsOpen() )
-						{
-							sendEvent( "\"%s\": %8.2f MB %d frames timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
-									   m_writer->GetFileName().c_str(), size, m_writer->GetFramesWritten(),
-									   timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
-									   recDate.tm_year + 1900, recDate.tm_mon + 1, recDate.tm_mday,
-									   recDate.tm_hour, recDate.tm_min, recDate.tm_sec );
-							if ( m_dropped_frames > 0 )
-								sendEvent( "Warning: %d dropped frames.", m_dropped_frames );
-							m_dropped_frames = 0;
-						}
-					}
-					pthread_mutex_unlock( &capture_mutex );
-				}
+					writeFrame( timeCode, recDate );
 
 				// drop frame on stdout if getting low on buffers
-				if ( !critical_mass && !isatty( fileno( stdout ) ) )
+				if ( !critical_mass && m_raw_pipe )
 				{
 					fd_set wfds;
 					struct timeval tv =
 					    {
 						    0, 20000
-					    }
-					    ;
+					    };
 					FD_ZERO( &wfds );
 					FD_SET( fileno( stdout ), &wfds );
 					if ( select( fileno( stdout ) + 1, NULL, &wfds, NULL, &tv ) )
@@ -725,7 +898,7 @@ void DVgrab::captureThreadRun()
 				}
 			}
 			m_reader->DoneWithFrame( m_frame );
-			prevTimeCode.sec = timeCode.sec;
+			m_prevTimeCode.sec = timeCode.sec;
 		}
 		else
 			// reader has erred or signaling a stop condition (end of pipe)
@@ -740,10 +913,10 @@ void DVgrab::status( )
 	char s[ 32 ];
 	unsigned int status;
 	static unsigned int prevStatus = 0;
-	static string transportStatus( "" );
-	static string timecode( "" );
-	static string filename( "" );
-	static string duration( "" );
+	std::string transportStatus( "" );
+	std::string timecode( "" );
+	std::string filename( "" );
+	std::string duration( "" );
 
 	if ( ! m_avc )
 		return ;
@@ -956,7 +1129,30 @@ bool DVgrab::isPlaying()
 
 bool DVgrab::done()
 {
-	timespec t = {0, 25000000};
-	nanosleep( &t, NULL );
-	return ! m_reader_active;
+	if ( m_reader_active )
+	{
+		timespec t = {0, 25000000};
+		return ( nanosleep( &t, NULL ) == -1 );
+	}
+	return true;
+}
+
+void DVgrab::cleanup()
+{
+	stopCapture();
+	if ( m_avc && !m_no_stop )
+		m_avc->Stop( m_node );
+	m_reader_active = false;
+	if ( m_reader )
+	{
+		m_reader->StopThread();
+		pthread_join( capture_thread, NULL );
+		delete m_reader;
+	}
+	if ( m_avc )
+		delete m_avc;
+	if ( m_connection )
+		delete m_connection;
+	if ( m_timeDuration )
+		delete m_timeDuration;
 }
