@@ -173,6 +173,12 @@ bool FileHandler::GetTimeSys() const
 }
 
 
+bool FileHandler::GetTimeCode() const
+{
+	return timeCode;
+}
+
+
 string FileHandler::GetBaseName() const
 {
 	return base;
@@ -229,6 +235,12 @@ void FileHandler::SetTimeSys( bool flag )
 }
 
 
+void FileHandler::SetTimeCode( bool flag )
+{
+	timeCode = flag;
+}
+
+
 void FileHandler::SetBaseName( const string& s )
 {
 	base = s;
@@ -330,24 +342,46 @@ bool FileHandler::WriteFrame( Frame& frame )
 		else if ( GetTimeSys() )
 		{
 TimeSys:
-			ostringstream	sb, sb2;
+			ostringstream sb;
 			time_t timesys;
 			struct tm date;
-			string recDate;
 			
 			time( &timesys );
 			localtime_r( &timesys, &date );
 			
-			sb << setfill( '0' )
+			sb << GetBaseName() 
+			<< setfill( '0' )
 			<< setw( 4 ) << date.tm_year + 1900 << '.'
 			<< setw( 2 ) << date.tm_mon + 1 << '.'
 			<< setw( 2 ) << date.tm_mday << '_'
 			<< setw( 2 ) << date.tm_hour << '-'
 			<< setw( 2 ) << date.tm_min << '-'
-			<< setw( 2 ) << date.tm_sec;
-			recDate = sb.str();
-			sb2 << GetBaseName() << recDate << GetExtension();
-			filename = sb2.str();
+			<< setw( 2 ) << date.tm_sec
+			<< GetExtension();
+			filename = sb.str();
+		}
+		else if ( GetTimeCode() )
+		{
+			ostringstream sb;
+			TimeCode tc;
+			
+			if ( frame.GetTimeCode( tc ) )
+			{	
+				sb << GetBaseName()
+				<< setfill( '0' )
+				<< setw( 2 ) << tc.hour << ':'
+				<< setw( 2 ) << tc.min << ':'
+				<< setw( 2 ) << tc.sec << ':'
+				<< setw( 2 ) << tc.frame
+				<< GetExtension();
+			}
+			else
+			{
+				sb << GetBaseName()
+				<< "EE:EE:EE:EE"
+				<< GetExtension();
+			}
+			filename = sb.str();
 		}
 		else
 		{
