@@ -37,6 +37,7 @@
 #include <iomanip>
 #include <deque>
 
+using std::string;
 using std::ostringstream;
 using std::setw;
 using std::setfill;
@@ -47,6 +48,7 @@ using std::endl;
 // C includes
 
 #include <pthread.h>
+#include <stdio.h>
 
 // local includes
 #include "frame.h"
