@@ -61,9 +61,9 @@ using std::endl;
 #include <sys/mman.h>
 #include <sys/poll.h>
 #include <errno.h>
+#include <time.h>
+#include <sys/time.h>
 
-#include <libraw1394/raw1394.h>
-#include <libraw1394/csr.h>
 #include <libavc1394/avc1394.h>
 #include <libavc1394/avc1394_vcr.h>
 #include <libavc1394/rom1394.h>
@@ -86,7 +86,9 @@ using std::endl;
  */
 
 
-IEEE1394Reader::IEEE1394Reader( int c, int bufSize ) : 
+IEEE1394Reader::IEEE1394Reader( int c, int bufSize ) :
+	droppedFrames( 0 ),
+	incompleteFrames( 0 ),
 	channel( c ),
 	isRunning( false )
 {
@@ -106,8 +108,6 @@ IEEE1394Reader::IEEE1394Reader( int c, int bufSize ) :
 	pthread_mutex_init( &condition_mutex, NULL );
 	pthread_cond_init( &condition, NULL );
 
-	/* Other */
-	droppedFrames = 0;
 }
 
 
@@ -203,6 +203,17 @@ int IEEE1394Reader::GetDroppedFrames( void )
 }
 
 
+/** Return the number of incomplete frames since last call
+*/
+
+int IEEE1394Reader::GetIncompleteFrames( void )
+{
+	int n = incompleteFrames;
+	incompleteFrames = 0;
+	return n;
+}
+
+
 /** Throw away all currently available frames.
  
     All frames in the outFrames queue are put back to the inFrames
@@ -225,7 +236,7 @@ void IEEE1394Reader::Flush()
 	}
 }
 
-bool IEEE1394Reader::WaitForAction( )
+bool IEEE1394Reader::WaitForAction( int seconds )
 {
 	pthread_mutex_lock( &mutex );
 	int size = outFrames.size( );
@@ -234,10 +245,32 @@ bool IEEE1394Reader::WaitForAction( )
 	if ( size == 0 )
 	{
 		pthread_mutex_lock( &condition_mutex );
-		pthread_cond_wait( &condition, &condition_mutex );
-		pthread_mutex_unlock( &condition_mutex );
-		pthread_mutex_lock( &mutex );
-		size = outFrames.size( );
+		if ( seconds == 0 )
+		{
+			pthread_cond_wait( &condition, &condition_mutex );
+			pthread_mutex_unlock( &condition_mutex );
+			pthread_mutex_lock( &mutex );
+			size = outFrames.size( );
+		}
+		else
+		{
+			struct timeval tp;
+			struct timespec ts;
+			int result;
+
+			gettimeofday( &tp, NULL );
+			ts.tv_sec = tp.tv_sec + seconds;
+			ts.tv_nsec = tp.tv_usec * 1000;
+
+			result = pthread_cond_timedwait( &condition, &condition_mutex, &ts );
+			pthread_mutex_unlock( &condition_mutex );
+			pthread_mutex_lock( &mutex );
+
+			if ( result == ETIMEDOUT )
+				size = 0;
+			else
+				size = outFrames.size();
+		}
 		pthread_mutex_unlock( &mutex );
 	}
 
@@ -264,16 +297,19 @@ void IEEE1394Reader::TriggerAction( )
  */
 
 
-raw1394Reader::raw1394Reader( int p, int c, int bufSize ) :
-		IEEE1394Reader( c, bufSize ), port( p )
+iec61883Reader::iec61883Reader( int p, int c, int bufSize,
+	BusResetHandler resetHandler, BusResetHandlerData data ) :
+		IEEE1394Reader( c, bufSize ), m_port( p ), m_resetHandler( resetHandler),
+		m_resetHandlerData( data )
 {
-	handle = NULL;
-	//cerr << ">>> Using raw1394 capture" << endl;
+	m_handle = NULL;
 }
 
 
-raw1394Reader::~raw1394Reader()
-{}
+iec61883Reader::~iec61883Reader()
+{
+	Close();
+}
 
 
 /** Start receiving DV frames
@@ -284,7 +320,7 @@ raw1394Reader::~raw1394Reader()
  
 */
 
-bool raw1394Reader::StartThread()
+bool iec61883Reader::StartThread()
 {
 	if ( isRunning )
 		return true;
@@ -316,14 +352,12 @@ bool raw1394Reader::StartThread()
  
 */
 
-void raw1394Reader::StopThread()
+void iec61883Reader::StopThread()
 {
 	if ( isRunning )
 	{
-		pthread_mutex_lock( &mutex );
 		isRunning = false;
 		pthread_join( thread, NULL );
-		pthread_mutex_unlock( &mutex );
 		StopReceive();
 		Close();
 		Flush();
@@ -332,33 +366,43 @@ void raw1394Reader::StopThread()
 }
 
 
+void iec61883Reader::ResetHandler( void )
+{
+	if ( m_resetHandler )
+		m_resetHandler( const_cast< void* >( m_resetHandlerData ) );
+}
+
+int iec61883Reader::ResetHandlerProxy( raw1394handle_t handle, unsigned int generation )
+{
+	iec61883_dv_t dv = static_cast< iec61883_dv_t >( raw1394_get_userdata( handle ) );
+	iec61883_dv_fb_t dvfb = static_cast< iec61883_dv_fb_t >( iec61883_dv_get_callback_data( dv ) );
+	iec61883Reader *self = static_cast< iec61883Reader* >( iec61883_dv_fb_get_callback_data( dvfb ) );
+	if ( self )
+		self->ResetHandler();
+	return 0;
+}
+
+
 /** Open the raw1394 interface
  
     \return success/failure
 */
 
-bool raw1394Reader::Open()
+bool iec61883Reader::Open()
 {
 	bool success;
-	int numcards;
-	struct raw1394_portinfo pinf[ 16 ];
-	iso_handler_t oldhandler;
 
-	assert( handle == NULL );
+	assert( m_handle == 0 );
 
 	try
 	{
-		handle = raw1394_new_handle();
-		if ( handle == 0 )
+		m_handle = raw1394_new_handle_on_port( m_port );
+		if ( m_handle == NULL )
 			return false;
-		fail_neg( numcards = raw1394_get_port_info( handle, pinf, 16 ) );
-		fail_neg( raw1394_set_port( handle, port ) );
-
-		oldhandler = raw1394_set_iso_handler( handle, channel, HandlerProxy );
-		raw1394_set_userdata( handle, this );
-
-		success = true;
+		raw1394_set_bus_reset_handler( m_handle, this->ResetHandlerProxy );
 
+		m_iec61883dv = iec61883_dv_fb_init( m_handle, HandlerProxy, this );
+		success = ( m_iec61883dv != NULL );
 	}
 	catch ( string exc )
 	{
@@ -374,23 +418,23 @@ bool raw1394Reader::Open()
  
 */
 
-void raw1394Reader::Close()
+void iec61883Reader::Close()
 {
-	if ( handle != NULL )
+	if ( m_iec61883dv != NULL )
 	{
-		raw1394_destroy_handle( handle );
-		handle = NULL;
+		iec61883_dv_fb_close( m_iec61883dv );
+		m_iec61883dv = NULL;
 	}
 }
 
-bool raw1394Reader::StartReceive()
+bool iec61883Reader::StartReceive()
 {
-	bool	success;
+	bool success;
 
 	/* Starting iso receive */
 	try
 	{
-		fail_neg( raw1394_start_iso_rcv( handle, channel ) );
+		fail_neg( iec61883_dv_fb_start( m_iec61883dv, channel ) );
 		success = true;
 	}
 	catch ( string exc )
@@ -402,123 +446,56 @@ bool raw1394Reader::StartReceive()
 }
 
 
-void raw1394Reader::StopReceive()
+void iec61883Reader::StopReceive()
 {
-	if ( handle != NULL )
-		raw1394_stop_iso_rcv( handle, channel );
-}
-
-
-/** assembles a DIF sequence to a DV frame
- 
-    The PAL/NTSC DV data has the following format:
- 
-    - packets of 496 bytes length
-    - packets of  16 bytes length.
- 
-    The long packets contain the actual video and audio contents that
-    goes into the AVI file.
-       
-    The actual DV data starts at quadlet 4 of the long packet, so we
-    have 480 bytes of DV data per packet.  For PAL, each rame is made
-    out of 300 packets and there are 25 frames per second.  That is
-    144000 bytes per frame and 3600000 bytes per second.  For NTSC we
-    have 250 packages per frame and 30 frames per second.  That is
-    120000 bytes per frame and 3600000 bytes per second too.
- 
-    We also attempt to detect incomplete frames. The idea is: If we
-    hit the begin of frame indicator and this is not the very first
-    packet for this frame, then at least one packed has been dropped
-    by the driver. This does not guarantee that no incomplete frames
-    are saved, because if we miss the frame header of the next frame,
-    we can´t tell whether the last one is incomplete.
- 
-    \param handle the handle to the ieee1394 subsystem
-    \param channel the channel this data has been read from
-    \param length the length of the data
-    \param data a pointer to the data
-    \return unused, we return always zero 
- 
-*/
-
-int raw1394Reader::HandlerProxy( raw1394handle_t handle, int channel, size_t length, quadlet_t *data )
-{
-	raw1394Reader *self = static_cast< raw1394Reader* >( raw1394_get_userdata( handle ) );
-	return self->Handler( channel, length, data );
-}
-
-int raw1394Reader::Handler( int channel, size_t length, quadlet_t *data )
-{
-	/* skip empty packets */
-
-	if ( length > 16 )
+	if ( m_iec61883dv != NULL )
 	{
-		unsigned char * p = ( unsigned char* ) & data[ 3 ];
-		int section_type = p[ 0 ] >> 5;           /* section type is in bits 5 - 7 */
-		int dif_sequence = p[ 1 ] >> 4;           /* dif sequence number is in bits 4 - 7 */
-		int dif_block = p[ 2 ];
-
-		/* if we are at the beginning of a frame, we put the previous
-		   frame in our output_queue.  Then we try to get an unused
-		   frame_buffer from the buffer_queue for the current frame.
-		   We must lock the queues because they are shared between
-		   this thread and the main thread. */
-		if ( section_type == 0 && dif_sequence == 0 )
-		{
-			pthread_mutex_lock( &mutex );
-			if ( currentFrame != NULL )
-			{
-				outFrames.push_back( currentFrame );
-				currentFrame = NULL;
-				//cerr << "reader > # inFrames: " << inFrames.size() << ", # outFrames: " << outFrames.size() << endl;
-				TriggerAction( );
-			}
-			if ( inFrames.size() > 0 )
-			{
-				currentFrame = inFrames.front();
-				currentFrame->bytesInFrame = 0;
-				inFrames.pop_front();
-				//if ( outFrames.size( ) >= 25 )
-				//cerr << "reader < # inFrames: " << inFrames.size() << ", # outFrames: " << outFrames.size() << endl;
-			}
-			else
-			{
-				droppedFrames++;
-				//cerr << "Warning: raw1394 dropped frames: " << droppedFrames << endl;
-			}
-			pthread_mutex_unlock( &mutex );
-		}
-		if ( currentFrame != NULL )
-		{
-			switch ( section_type )
-			{
-			case 0:    /* 1 Header block */
-				/* p[3] |= 0x80; // hack to force PAL data */
-				memcpy( currentFrame->data + dif_sequence * 150 * 80, p, 480 );
-				break;
-
-			case 1:    /* 2 Subcode blocks */
-				memcpy( currentFrame->data + dif_sequence * 150 * 80 + ( 1 + dif_block ) * 80, p, 480 );
-				break;
-
-			case 2:    /* 3 VAUX blocks */
-				memcpy( currentFrame->data + dif_sequence * 150 * 80 + ( 3 + dif_block ) * 80, p, 480 );
-				break;
-
-			case 3:    /* 9 Audio blocks interleaved with video */
-				memcpy( currentFrame->data + dif_sequence * 150 * 80 + ( 6 + dif_block * 16 ) * 80, p, 480 );
-				break;
-
-			case 4:    /* 135 Video blocks interleaved with audio */
-				memcpy( currentFrame->data + dif_sequence * 150 * 80 + ( 7 + ( dif_block / 15 ) + dif_block ) * 80, p, 480 );
-				break;
-
-			default:    /* we can´t handle any other data */
-				break;
-			}
-			currentFrame->bytesInFrame += 480;
-		}
+		iec61883_dv_fb_close( m_iec61883dv );
+		m_iec61883dv = NULL;
 	}
+}
+
+int iec61883Reader::HandlerProxy( unsigned char *data, int length, int complete, 
+	void *callback_data )
+{
+	iec61883Reader *self = static_cast< iec61883Reader* >( callback_data );
+	return self->Handler( length, complete, data );
+}
+
+int iec61883Reader::Handler( int length, int complete, unsigned char *data )
+{
+	pthread_mutex_lock( &mutex );
+	if ( currentFrame != NULL )
+	{
+		outFrames.push_back( currentFrame );
+		currentFrame = NULL;
+		//cerr << "reader > # inFrames: " << inFrames.size() << ", # outFrames: " << outFrames.size() << endl;
+		TriggerAction( );
+	}
+	if ( inFrames.size() > 0 )
+	{
+		currentFrame = inFrames.front();
+		currentFrame->bytesInFrame = 0;
+		inFrames.pop_front();
+		//if ( outFrames.size( ) >= 25 )
+		//cerr << "reader < # inFrames: " << inFrames.size() << ", # outFrames: " << outFrames.size() << endl;
+	}
+	else
+	{
+		droppedFrames++;
+		//cerr << "Warning: raw1394 dropped frames: " << droppedFrames << endl;
+	}
+	pthread_mutex_unlock( &mutex );
+
+	if ( currentFrame != NULL )
+	{
+		memcpy( currentFrame->data, data, length );
+		currentFrame->bytesInFrame = currentFrame->GetFrameSize( );
+	}
+
+	if ( !complete )
+		incompleteFrames++;
+
 	return 0;
 }
 
@@ -529,18 +506,18 @@ int raw1394Reader::Handler( int channel, size_t length, quadlet_t *data )
     but only in the pthread_testcancel() function.
  
 */
-void* raw1394Reader::ThreadProxy( void* arg )
+void* iec61883Reader::ThreadProxy( void* arg )
 {
-	raw1394Reader* self = static_cast< raw1394Reader* >( arg );
+	iec61883Reader* self = static_cast< iec61883Reader* >( arg );
 	return self->Thread();
 }
 
-void* raw1394Reader::Thread()
+void* iec61883Reader::Thread()
 {
 	struct pollfd raw1394_poll;
 	int result;
 		
-	raw1394_poll.fd = raw1394_get_fd( handle );
+	raw1394_poll.fd = raw1394_get_fd( m_handle );
 	raw1394_poll.events = POLLIN | POLLERR | POLLHUP | POLLPRI;
 
 	while ( isRunning )
@@ -555,274 +532,51 @@ void* raw1394Reader::Thread()
 		}
 		if ( result > 0 && ( ( raw1394_poll.revents & POLLIN )
 		        || ( raw1394_poll.revents & POLLPRI ) ) )
-			result = raw1394_loop_iterate( handle );
+			result = raw1394_loop_iterate( m_handle );
 	}
 	return NULL;
 }
 
 
-
-/** Initializes the dv1394Reader object.
- 
-    \param c the iso channel number to use
-    \param bufSize the number of frames to allocate for the frames buffer
- */
-
-
-dv1394Reader::dv1394Reader( char *device, int c, int bufSize ) :
-		IEEE1394Reader( c, bufSize )
+iec61883Connection::iec61883Connection( int port, int node ) :
+	m_node( node | 0xffc0 ), m_channel( -1 ), m_bandwidth( 0 ),
+	m_outputPort( -1 ), m_inputPort( -1 )
 {
-	m_dv1394_map = NULL;
-	m_dv1394_fd = -1;
-	m_device_file = device;
-	//cerr << ">>> Using dv1394 capture" << endl;
-}
-
-
-dv1394Reader::~dv1394Reader()
-{}
-
-
-/** Start receiving DV frames
- 
-    The ieee1394 subsystem is initialized with the parameters provided
-    to the constructor (port and channel).  The received frames can be
-    retrieved from the outFrames queue.
- 
-*/
-
-bool dv1394Reader::StartThread()
-{
-	if ( isRunning )
-		return true;
-	pthread_mutex_lock( &mutex );
-	currentFrame = NULL;
-	if ( Open() && StartReceive() )
+	m_handle = raw1394_new_handle_on_port( port );
+	if ( m_handle )
 	{
-		isRunning = true;
-		pthread_create( &thread, NULL, ThreadProxy, this );
-		pthread_mutex_unlock( &mutex );
-		return true;
-	}
-	else
-	{
-		Close();
-		pthread_mutex_unlock( &mutex );
-		return false;
+		m_channel = iec61883_cmp_connect( m_handle, m_node, &m_outputPort,
+			raw1394_get_local_id( m_handle ), &m_inputPort, &m_bandwidth );
+		if ( m_channel < 0 )
+			m_channel = 63;
 	}
 }
 
-
-/** Stop the receiver thread.
- 
-    The receiver thread is being canceled. It will finish the next
-    time it calls the pthread_testcancel() function.  After it is
-    canceled, we turn off iso receive and close the ieee1394
-    subsystem.  We also remove all frames in the outFrames queue that
-    have not been processed until now.
-
-*/
-
-void dv1394Reader::StopThread()
+iec61883Connection::~iec61883Connection( )
 {
-	if ( isRunning )
+	if ( m_handle )
 	{
-		pthread_mutex_lock( &mutex );
-		isRunning = false;
-		pthread_join( thread, NULL );
-		pthread_mutex_unlock( &mutex );
-		StopReceive();
-		Close();
-		Flush();
+		iec61883_cmp_disconnect( m_handle, m_node, m_outputPort,
+			raw1394_get_local_id (m_handle), m_inputPort,
+			m_channel, m_bandwidth );
+		raw1394_destroy_handle( m_handle );
 	}
 }
 
-
-/** Open the dv1394 interface
- 
-    \return success/failure
-*/
-
-bool dv1394Reader::Open()
+void iec61883Connection::CheckConsistency( int port, int node )
 {
-	int n_frames = DV1394_MAX_FRAMES / 4;
-	struct dv1394_init init =
-	    {
-		    DV1394_API_VERSION, channel, n_frames, DV1394_PAL, 0, 0, 0
-	    };
-
-	m_dv1394_fd = open( m_device_file, O_RDWR );
-	if ( m_dv1394_fd == -1 )
-	{
-		perror( "dv1394 open" );
-		cerr << "dv1394 open: " << m_device_file << endl;
-		return false;
-	}
-
-	if ( ioctl( m_dv1394_fd, DV1394_INIT, &init ) )
-	{
-		perror( "dv1394 INIT ioctl" );
-		close( m_dv1394_fd );
-		m_dv1394_fd = -1;
-		return false;
-	}
-
-	m_dv1394_map = ( unsigned char * ) mmap( NULL, DV1394_PAL_FRAME_SIZE * n_frames,
-	               PROT_READ | PROT_WRITE, MAP_SHARED, m_dv1394_fd, 0 );
-	if ( m_dv1394_map == MAP_FAILED )
-	{
-		perror( "mmap frame buffers" );
-		close( m_dv1394_fd );
-		m_dv1394_fd = -1;
-		m_dv1394_map = NULL;
-		return false;
-	}
-
-	return true;
+	raw1394handle_t handle = raw1394_new_handle_on_port( port );
+	if ( handle )
+		iec61883_cmp_normalize_output( handle, 0xffc0 | node );
+	raw1394_destroy_handle( handle );
 }
 
 
-/** Close the dv1394 interface
- 
-*/
-void dv1394Reader::Close()
+int iec61883Connection::Reconnect( void )
 {
-	if ( m_dv1394_fd != -1 )
-	{
-		if ( m_dv1394_map != NULL )
-			munmap( m_dv1394_map, DV1394_PAL_FRAME_SIZE * DV1394_MAX_FRAMES / 4 );
-		close( m_dv1394_fd );
-		m_dv1394_map = NULL;
-		m_dv1394_fd = -1;
-	}
-}
-
-
-bool dv1394Reader::StartReceive()
-{
-	/* Starting iso receive */
-	if ( ioctl( m_dv1394_fd, DV1394_START_RECEIVE, NULL ) )
-	{
-		perror( "dv1394 START_RECEIVE ioctl" );
-		return false;
-	}
-	return true;
-}
-
-
-void dv1394Reader::StopReceive()
-{}
-
-bool dv1394Reader::Handler( int handle )
-{
-	struct dv1394_status dvst;
-	struct pollfd pol;
-		
-	pol.fd = m_dv1394_fd;
-	pol.events = POLLIN | POLLERR | POLLHUP;
-	while ( poll( &pol, 1, -1 ) < 0 )
-	{
-		if ( !( errno == EAGAIN || errno == EINTR ) )
-		{
-			perror( "error: dv1394 poll" );
-			return false;
-		}
-	}
-
-	if ( ioctl( handle, DV1394_GET_STATUS, &dvst ) )
-	{
-		perror( "ioctl GET_STATUS" );
-		return false;
-	}
-
-	if ( dvst.dropped_frames > 0 )
-	{
-		droppedFrames += dvst.dropped_frames;
-	}
-
-	for ( unsigned int i = 0; i < dvst.n_clear_frames; i++ )
-	{
-		pthread_mutex_lock( &mutex );
-		if ( currentFrame != NULL )
-		{
-			outFrames.push_back( currentFrame );
-			currentFrame = NULL;
-			TriggerAction( );
-			//printf("reader > out: buffer %d, output %d\n", inFrames.size(), outFrames.size());
-			//fflush(stdout);
-		}
-
-
-		if ( inFrames.size() > 0 )
-		{
-			currentFrame = inFrames.front();
-			currentFrame->bytesInFrame = 0;
-			inFrames.pop_front();
-			//printf("reader < buf: buffer %d, output %d\n", inFrames.size(), outFrames.size());
-			//fflush(stdout);	if ( isRunning )
-	{
-		pthread_mutex_lock( &mutex );
-		isRunning = false;
-		pthread_join( thread, NULL );
-		pthread_mutex_unlock( &mutex );
-		StopReceive();
-		Close();
-		Flush();
-	}
-
-		}
-		else
-		{
-			droppedFrames++;
-			//cerr << "reader < # dropped frames: " << droppedFrames << endl;
-		}
-
-		pthread_mutex_unlock( &mutex );
-
-		if ( currentFrame != NULL )
-		{
-			memcpy( currentFrame->data,
-			        ( m_dv1394_map + ( dvst.first_clear_frame * DV1394_PAL_FRAME_SIZE ) ),
-			        DV1394_PAL_FRAME_SIZE );
-			currentFrame->bytesInFrame = currentFrame->GetFrameSize( );
-		}
-
-		if ( ioctl( handle, DV1394_RECEIVE_FRAMES, 1 ) )
-		{
-			perror( "error: ioctl RECEIVE_FRAMES" );
-			return false;
-		}
-
-		if ( ioctl( handle, DV1394_GET_STATUS, &dvst ) )
-		{
-			perror( "ioctl GET_STATUS" );
-			return false;
-		}
-	}
-	return true;
-}
-
-
-/** The thread responsible for polling the dv1394 interface.
- 
-    Though this is an infinite loop, it can be canceled by StopThread,
-    but only in the pthread_testcancel() function.
- 
-*/
-void* dv1394Reader::ThreadProxy( void* arg )
-{
-	dv1394Reader* self = static_cast< dv1394Reader* >( arg );
-	return self->Thread();
-}
-
-void* dv1394Reader::Thread()
-{
-	while ( isRunning )
-	{
-		if ( ! Handler( m_dv1394_fd ) )
-			break;
-	}
-	return NULL;
+	return iec61883_cmp_reconnect( m_handle, m_node, &m_outputPort,
+		raw1394_get_local_id( m_handle ), &m_inputPort,
+		&m_bandwidth, m_channel );
 }
 
 
@@ -847,8 +601,6 @@ AVC::AVC( int p ) : port( p )
 		fail_neg( numcards = raw1394_get_port_info( avc_handle, pinf, 16 ) );
 		fail_neg( raw1394_set_port( avc_handle, port ) );
 
-		raw1394_set_bus_reset_handler( avc_handle, this->ResetHandler );
-
 	}
 	catch ( string exc )
 	{
@@ -877,15 +629,6 @@ AVC::~AVC()
 }
 
 
-int AVC::ResetHandler( raw1394handle_t handle, unsigned int generation )
-{
-	cerr << "Reset Handler received" << endl;
-	raw1394_update_generation( handle, generation );
-	//common->getPageCapture()->driver_locked = true;
-	return 0;
-}
-
-
 /** See if a node_id is still valid and pointing to an AV/C Recorder.
  
 	If the node_id is not valid, then look for the first AV/C device on
@@ -928,7 +671,7 @@ int AVC::isPhyIDValid( int phyID )
 				if ( avc1394_check_subunit_type( avc_handle, currentNode, AVC1394_SUBUNIT_TYPE_VCR ) )
 				{
 					// set Preferences to the newly found AVC node and return
-					octlet_t guid = rom1394_get_guid( avc_handle, currentNode );
+					//octlet_t guid = rom1394_get_guid( avc_handle, currentNode );
 					//snprintf( Preferences::getInstance().avcGUID, 64, "%08x%08x", (quadlet_t) (guid>>32),
 					//(quadlet_t) (guid & 0xffffffff) );
 					value = currentNode;
