@@ -129,6 +129,9 @@ int discoverAVC( int* port, octlet_t guid )
 				if ( ( rom1394_get_node_type( &rom_dir ) == ROM1394_NODE_TYPE_AVC ) &&
 				        avc1394_check_subunit_type( handle, i, AVC1394_SUBUNIT_TYPE_VCR ) )
 				{
+					guid = rom1394_get_guid( handle, i );
+					fprintf( stderr, "Found AV/C device with GUID 0x%08x%08x\n",
+						(quadlet_t) (guid>>32), (quadlet_t) (guid & 0xffffffff));
 					device = i;
 					*port = j;
 					break;
